@@ -5,12 +5,12 @@ from ..encoder import EncoderConfig
 
 
 @dataclass(frozen=True)
-class MPIConfig:
+class ClientConfig:
     """
-    Represents pseudonyms in a special domain so that they may be resolved to their original identifiers.
+    Represents a client configuration containing domain-specific data.
     """
-    domain: str
-    pseudonyms: List[str] = field(default_factory=list)
+    domain: str = ""
+    attributes: List[str] = field(default_factory=lambda: ["birth_date", "first_name", "last_name", "gender"])
 
 
 @dataclass(frozen=True)
@@ -18,9 +18,9 @@ class ResolveRequest:
     """
     Represents a request to resolve and submit pseudonyms to a broker service.
     """
-    mpi_config: MPIConfig = field(default_factory=MPIConfig)
+    client_config: ClientConfig = field(default_factory=ClientConfig)
     encoder_config: EncoderConfig = field(default_factory=EncoderConfig)
-    attribute_list: List[str] = field(default_factory=lambda: ["birth_date", "first_name", "last_name", "gender"])
+    pseudonyms: List[str] = field(default_factory=list)
 
 
 @dataclass(frozen=True)
